==> alliance-1.1.tar.gz: alliance-1.1/tools/sl/sce/decomp/not1.c <==
/**********************************************/
/*** Fonction permettant de creer une Befig ***/
/*** a partir du code genere par la lecture ***/
/*** de la Befig obtenue par le compilateur ***/
/***       fichier compile : not1.vbe ***/
/**********************************************/

#include <stdio.h>
#include "mut309.h"
#include "log120.h"
#include "beh104.h"

befig_list *not1()
{
befig_list *befigAux;
chain_list *abl;
begen_list *genAux = NULL;
int *pentier;
befigAux = beh_addbefig(NULL,namealloc("not1"));
befigAux->BERIN = beh_addberin(befigAux->BERIN,namealloc("vss"));
befigAux->BERIN = beh_addberin(befigAux->BERIN,namealloc("vdd"));
befigAux->BERIN = beh_addberin(befigAux->BERIN,namealloc("i"));
befigAux->BEPOR = beh_addbepor(befigAux->BEPOR,namealloc("vss"),'I','B');
befigAux->BEPOR = beh_addbepor(befigAux->BEPOR,namealloc("vdd"),'I','B');
befigAux->BEPOR = beh_addbepor(befigAux->BEPOR,namealloc("f"),'O','B');
befigAux->BEPOR = beh_addbepor(befigAux->BEPOR,namealloc("i"),'I','B');
befigAux->BEPOR = (bepor_list *)reverse((chain_list *)befigAux->BEPOR);
abl = charToExpr("(not i)");
befigAux->BEOUT = beh_addbeout(befigAux->BEOUT,namealloc("f"),abl,NULL);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 1287;
genAux = beh_addbegen(genAux,"rup_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 225;
genAux = beh_addbegen(genAux,"tplh_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 1587;
genAux = beh_addbegen(genAux,"rdown_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 215;
genAux = beh_addbegen(genAux,"tphl_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 51;
genAux = beh_addbegen(genAux,"cin_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 316;
genAux = beh_addbegen(genAux,"fanout","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 2;
genAux = beh_addbegen(genAux,"area","natural",(void *)pentier);
befigAux->USER = addptype(NULL,BEH_GENERIC,(void *)genAux);
befigAux->CIRCUI = NULL;
befigAux->NEXT = NULL;
abl = charToExpr("(not (xor (not (xor (and (not (xor vdd '1')) (not (xor vss '0'))) '1')) '1'))");
befigAux->BEMSG = beh_addbemsg(befigAux->BEMSG,NULL,'W',"power supply is missing on not1",abl,NULL);

return befigAux;
}

==> alliance-1.2.tar.gz: alliance-1.2/tools/sl/sce/decomp/not1.c <==
/**********************************************/
/*** Fonction permettant de creer une Befig ***/
/*** a partir du code genere par la lecture ***/
/*** de la Befig obtenue par le compilateur ***/
/***       fichier compile : not1.vbe ***/
/**********************************************/

#include <stdio.h>
#include "mut309.h"
#include "log120.h"
#include "beh104.h"

befig_list *not1()
{
befig_list *befigAux;
chain_list *abl;
begen_list *genAux = NULL;
int *pentier;
befigAux = beh_addbefig(NULL,namealloc("not1"));
befigAux->BERIN = beh_addberin(befigAux->BERIN,namealloc("vss"));
befigAux->BERIN = beh_addberin(befigAux->BERIN,namealloc("vdd"));
befigAux->BERIN = beh_addberin(befigAux->BERIN,namealloc("i"));
befigAux->BEPOR = beh_addbepor(befigAux->BEPOR,namealloc("vss"),'I','B');
befigAux->BEPOR = beh_addbepor(befigAux->BEPOR,namealloc("vdd"),'I','B');
befigAux->BEPOR = beh_addbepor(befigAux->BEPOR,namealloc("f"),'O','B');
befigAux->BEPOR = beh_addbepor(befigAux->BEPOR,namealloc("i"),'I','B');
befigAux->BEPOR = (bepor_list *)reverse((chain_list *)befigAux->BEPOR);
abl = charToExpr("(not i)");
befigAux->BEOUT = beh_addbeout(befigAux->BEOUT,namealloc("f"),abl,NULL);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 3060;
genAux = beh_addbegen(genAux,"rup_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 734;
genAux = beh_addbegen(genAux,"tplh_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 2089;
genAux = beh_addbegen(genAux,"rdown_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 501;
genAux = beh_addbegen(genAux,"tphl_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 40;
genAux = beh_addbegen(genAux,"cin_i","natural",(void *)pentier);
pentier = (int *) mbkalloc(sizeof(int));
*pentier = 504;
genAux = beh_addbegen(genAux,"area","natural",(void *)pentier);
befigAux->BEGEN = genAux;
befigAux->CIRCUI = NULL;
befigAux->NEXT = NULL;
abl = charToExpr("(and vdd (not vss))");
befigAux->BEMSG = beh_addbemsg(befigAux->BEMSG,NULL,'W',"power supply is missing on n1_y",abl,NULL);

return befigAux;
}
